Gentelella Alela! |

Welcome,

## John Doe

### Form Buttons

## Default Buttons

## Rounded Button

## Button Dropdown

## Split Button Dropdown

## Button App Design

Add the class `.btn .btn-app` tag

Edit Play Pause Save 6 Notifications Repeat 211 Users 32 Orders 12 Inbox 102 Likes

## Button Sizes

## Button Groups

Vertical button groups

Nested button groups

Multiple button groups

Group Radio

Option 1 Option 2 Option 3